@@ -15,6 +15,7 @@ static PetscBool EPSPackageInitialized = PETSC_FALSE;
 const char *EPSBalanceTypes[] = {"NONE","ONESIDE","TWOSIDE","USER","EPSBalance","EPS_BALANCE_",NULL};
 const char *EPSErrorTypes[] = {"ABSOLUTE","RELATIVE","BACKWARD","EPSErrorType","EPS_ERROR_",NULL};
 const char *EPSPowerShiftTypes[] = {"CONSTANT","RAYLEIGH","WILKINSON","EPSPowerShiftType","EPS_POWER_SHIFT_",NULL};
+const char *EPSKrylovSchurBSETypes[] = {"SHAO","GRUNING","PROJECTEDBSE","EPSKrylovSchurBSEType","EPS_KRYLOVSCHUR_BSE_",NULL};
 const char *EPSLanczosReorthogTypes[] = {"LOCAL","FULL","SELECTIVE","PERIODIC","PARTIAL","DELAYED","EPSLanczosReorthogType","EPS_LANCZOS_REORTHOG_",NULL};
 const char *EPSPRIMMEMethods[] = {"","DYNAMIC","DEFAULT_MIN_TIME","DEFAULT_MIN_MATVECS","ARNOLDI","GD","GD_PLUSK","GD_OLSEN_PLUSK","JD_OLSEN_PLUSK","RQI","JDQR","JDQMR","JDQMR_ETOL","SUBSPACE_ITERATION","LOBPCG_ORTHOBASIS","LOBPCG_ORTHOBASISW","EPSPRIMMEMethod","EPS_PRIMME_",NULL};
 const char *EPSCISSQuadRules[] = {"(not set yet)","TRAPEZOIDAL","CHEBYSHEV","EPSCISSQuadRule","EPS_CISS_QUADRULE_",NULL};
@@ -26,11 +27,11 @@ const char *const*EPSConvergedReasons = EPSConvergedReasons_Shifted + 4;
 
 /*@C
   EPSFinalizePackage - This function destroys everything in the SLEPc interface
-  to the EPS package. It is called from SlepcFinalize().
+  to the `EPS` package. It is called from `SlepcFinalize()`.
 
   Level: developer
 
-.seealso: SlepcFinalize()
+.seealso: [](ch:eps), `SlepcFinalize()`, `EPSInitializePackage()`
 @*/
 PetscErrorCode EPSFinalizePackage(void)
 {
@@ -42,26 +43,29 @@ PetscErrorCode EPSFinalizePackage(void)
   EPSPackageInitialized       = PETSC_FALSE;
   EPSRegisterAllCalled        = PETSC_FALSE;
   EPSMonitorRegisterAllCalled = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  EPSInitializePackage - This function initializes everything in the EPS package.
-  It is called from PetscDLLibraryRegister() when using dynamic libraries, and
-  on the first call to EPSCreate() when using static libraries.
+   EPSInitializePackage - This function initializes everything in the `EPS` package.
+   It is called from `PetscDLLibraryRegister_slepceps()` when using dynamic libraries, and
+   on the first call to `EPSCreate()` when using shared or static libraries.
 
-  Level: developer
+   Note:
+   This function never needs to be called by SLEPc users.
 
-.seealso: SlepcInitialize()
+   Level: developer
+
+.seealso: [](ch:eps), `EPS`, `SlepcInitialize()`, `EPSFinalizePackage()`
 @*/
-PetscErrorCode EPSInitializePackage()
+PetscErrorCode EPSInitializePackage(void)
 {
   char           logList[256];
   PetscBool      opt,pkg;
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (EPSPackageInitialized) PetscFunctionReturn(0);
+  if (EPSPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   EPSPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("EPS Solver",&EPS_CLASSID));
@@ -84,7 +88,7 @@ PetscErrorCode EPSInitializePackage()
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(EPSFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_DYNAMIC_LIBRARIES)
@@ -95,10 +99,10 @@ PetscErrorCode EPSInitializePackage()
   This one registers all the EPS methods that are in the basic SLEPc libslepceps
   library.
  */
-SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepceps()
+SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepceps(void)
 {
   PetscFunctionBegin;
   PetscCall(EPSInitializePackage());
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif /* PETSC_HAVE_DYNAMIC_LIBRARIES */
