@@ -24,12 +24,12 @@ const char *PEPJDProjectionTypes[] = {"HARMONIC","ORTHOGONAL","PEPJDProjection",
 const char *PEPCISSExtractions[] = {"RITZ","HANKEL","CAA","PEPCISSExtraction","PEP_CISS_EXTRACTION_",NULL};
 
 /*@C
-   PEPFinalizePackage - This function destroys everything in the Slepc interface
-   to the PEP package. It is called from SlepcFinalize().
+  PEPFinalizePackage - This function destroys everything in the SLEPc interface
+  to the `PEP` package. It is called from `SlepcFinalize()`.
 
-   Level: developer
+  Level: developer
 
-.seealso: SlepcFinalize()
+.seealso: [](ch:pep), `SlepcFinalize()`, `PEPInitializePackage()`
 @*/
 PetscErrorCode PEPFinalizePackage(void)
 {
@@ -41,17 +41,20 @@ PetscErrorCode PEPFinalizePackage(void)
   PEPPackageInitialized       = PETSC_FALSE;
   PEPRegisterAllCalled        = PETSC_FALSE;
   PEPMonitorRegisterAllCalled = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PEPInitializePackage - This function initializes everything in the PEP package.
-   It is called from PetscDLLibraryRegister() when using dynamic libraries, and
-   on the first call to PEPCreate() when using static libraries.
+   PEPInitializePackage - This function initializes everything in the `PEP` package.
+   It is called from `PetscDLLibraryRegister_slepcpep()` when using dynamic libraries, and
+   on the first call to `PEPCreate()` when using shared or static libraries.
+
+   Note:
+   This function never needs to be called by SLEPc users.
 
    Level: developer
 
-.seealso: SlepcInitialize()
+.seealso: [](ch:pep), `PEP`, `SlepcInitialize()`, `PEPFinalizePackage()`
 @*/
 PetscErrorCode PEPInitializePackage(void)
 {
@@ -60,7 +63,7 @@ PetscErrorCode PEPInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (PEPPackageInitialized) PetscFunctionReturn(0);
+  if (PEPPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   PEPPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("PEP Solver",&PEP_CLASSID));
@@ -84,7 +87,7 @@ PetscErrorCode PEPInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(PEPFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_DYNAMIC_LIBRARIES)
@@ -95,10 +98,10 @@ PetscErrorCode PEPInitializePackage(void)
   This one registers all the PEP methods that are in the basic SLEPc libslepcpep
   library.
  */
-SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcpep()
+SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcpep(void)
 {
   PetscFunctionBegin;
   PetscCall(PEPInitializePackage());
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif /* PETSC_HAVE_DYNAMIC_LIBRARIES */
