@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2017, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -13,77 +13,75 @@
 
 #include <slepc/private/vecimplslepc.h>       /*I "slepcvec.h" I*/
 
-/*@C
+/*
    SlepcVecPoolCreate - Create a pool of Vec.
 
-   Collective on VecPool
+   Collective
 
    Input Parameters:
 +  v - template vector.
 -  init_size - first guess of maximum vectors.
 
    Output Parameter:
-.  pool - the pool context.
+.  p - the pool context.
 
    Level: developer
 
-.seealso: SlepcVecPoolGetVecs(), SlepcVecPoolDestroy()
-@*/
+.seealso: `SlepcVecPoolGetVecs()`, `SlepcVecPoolDestroy()`
+*/
 PetscErrorCode SlepcVecPoolCreate(Vec v,PetscInt init_size,VecPool *p)
 {
-  PetscErrorCode ierr;
   VecPool_       *pool;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v,VEC_CLASSID,1);
   PetscValidLogicalCollectiveInt(v,init_size,2);
-  PetscValidPointer(p,3);
-  if (init_size<0) SETERRQ(PetscObjectComm((PetscObject)v),PETSC_ERR_ARG_WRONG,"init_size should be positive");
-  ierr = PetscCalloc1(1,&pool);CHKERRQ(ierr);
-  ierr = PetscObjectReference((PetscObject)v);CHKERRQ(ierr);
+  PetscAssertPointer(p,3);
+  PetscCheck(init_size>=0,PetscObjectComm((PetscObject)v),PETSC_ERR_ARG_WRONG,"init_size should be positive");
+  PetscCall(PetscCalloc1(1,&pool));
+  PetscCall(PetscObjectReference((PetscObject)v));
   pool->v     = v;
   pool->guess = init_size;
   *p = pool;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*
    SlepcVecPoolDestroy - Destroy the pool of Vec.
 
-   Collective on VecPool
+   Collective
 
-   Input Parameters:
-.  pool - pool of Vec.
+   Input Parameter:
+.  p - pool of Vec.
 
    Level: developer
 
-.seealso: SlepcVecPoolGetVecs(), SlepcVecPoolCreate()
-@*/
+.seealso: `SlepcVecPoolGetVecs()`, `SlepcVecPoolCreate()`
+*/
 PetscErrorCode SlepcVecPoolDestroy(VecPool *p)
 {
-  PetscErrorCode ierr;
   VecPool_       *pool = (VecPool_*)*p;
 
   PetscFunctionBegin;
-  if (!*p) PetscFunctionReturn(0);
-  ierr = VecDestroy(&pool->v);CHKERRQ(ierr);
-  ierr = VecDestroyVecs(pool->n,&pool->vecs);CHKERRQ(ierr);
+  if (!*p) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCall(VecDestroy(&pool->v));
+  PetscCall(VecDestroyVecs(pool->n,&pool->vecs));
   pool->n     = 0;
   pool->used  = 0;
   pool->guess = 0;
-  ierr = SlepcVecPoolDestroy((VecPool*)&pool->next);CHKERRQ(ierr);
-  ierr = PetscFree(pool);CHKERRQ(ierr);
+  PetscCall(SlepcVecPoolDestroy((VecPool*)&pool->next));
+  PetscCall(PetscFree(pool));
   *p = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*
    SlepcVecPoolGetVecs - Get an array of Vec from the pool.
 
-   Collective on VecPool
+   Collective
 
    Input Parameters:
-+  pool - pool of Vec.
++  p - pool of Vec.
 -  n - number of vectors.
 
    Output Parameter:
@@ -91,64 +89,60 @@ PetscErrorCode SlepcVecPoolDestroy(VecPool *p)
 
    Level: developer
 
-.seealso: SlepcVecPoolRestoreVecs()
-@*/
+.seealso: `SlepcVecPoolRestoreVecs()`
+*/
 PetscErrorCode SlepcVecPoolGetVecs(VecPool p,PetscInt n,Vec **vecs)
 {
-  PetscErrorCode ierr;
   VecPool_       *pool = (VecPool_*)p;
 
   PetscFunctionBegin;
-  PetscValidPointer(p,1);
-  PetscValidPointer(vecs,3);
-  if (n<0) SETERRQ(PetscObjectComm((PetscObject)pool->v),PETSC_ERR_ARG_OUTOFRANGE,"n should be positive");
+  PetscAssertPointer(p,1);
+  PetscAssertPointer(vecs,3);
+  PetscCheck(n>=0,PetscObjectComm((PetscObject)pool->v),PETSC_ERR_ARG_OUTOFRANGE,"n should be positive");
   while (pool->next) pool = pool->next;
   if (pool->n-pool->used < n) {
     pool->guess = PetscMax(p->guess,pool->used+n);
-    if (pool->vecs && pool->used == 0) {
-      ierr = VecDestroyVecs(pool->n,&pool->vecs);CHKERRQ(ierr);
-    }
+    if (pool->vecs && pool->used == 0) PetscCall(VecDestroyVecs(pool->n,&pool->vecs));
     if (pool->vecs) {
-      ierr = SlepcVecPoolCreate(p->v,pool->guess-pool->used,&pool->next);CHKERRQ(ierr);
+      PetscCall(SlepcVecPoolCreate(p->v,pool->guess-pool->used,&pool->next));
       pool = pool->next;
     }
     pool->n = pool->guess;
-    ierr = VecDuplicateVecs(p->v,pool->n,&pool->vecs);CHKERRQ(ierr);
+    PetscCall(VecDuplicateVecs(p->v,pool->n,&pool->vecs));
   }
   *vecs = pool->vecs + pool->used;
   pool->used += n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*
    SlepcVecPoolRestoreVecs - Get back an array of Vec previously returned by
    SlepcVecPoolGetVecs().
 
-   Collective on VecPool
+   Collective
 
    Input Parameters:
-+  pool - pool of Vec.
-.  n - number of vectors.
++  p    - pool of Vec.
+.  n    - number of vectors.
 -  vecs - vectors
 
    Level: developer
 
-.seealso: SlepcVecPoolGetVecs()
-@*/
+.seealso: `SlepcVecPoolGetVecs()`
+*/
 PetscErrorCode SlepcVecPoolRestoreVecs(VecPool p,PetscInt n,Vec **vecs)
 {
-  PetscErrorCode ierr;
   VecPool_       *pool = (VecPool_*)p, *pool0 = pool;
 
   PetscFunctionBegin;
   while (pool->next) pool = (pool0 = pool)->next;
   if (pool->used == 0 && pool0 != pool) {
     pool0->guess = pool0->used + pool->guess;
-    ierr = SlepcVecPoolDestroy((VecPool*)&pool);CHKERRQ(ierr);
+    PetscCall(SlepcVecPoolDestroy((VecPool*)&pool));
     pool = pool0;
     pool->next = NULL;
   }
   pool->used -= n;
-  if (pool->used < 0) SETERRQ(PetscObjectComm((PetscObject)pool->v),PETSC_ERR_ARG_OUTOFRANGE,"Unmatched SlepcVecPoolRestoreVecs");
-  PetscFunctionReturn(0);
+  PetscCheck(pool->used>=0,PetscObjectComm((PetscObject)pool->v),PETSC_ERR_ARG_OUTOFRANGE,"Unmatched SlepcVecPoolRestoreVecs");
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
